==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/General/statusicon/translations/statusicon_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="zh_CN">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Status Icon Plugin Settings</source>
        <translation>状态图标插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Show message</source>
        <translation>显示消息</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="26"/>
        <source>Show tooltip</source>
        <translation>显示工具提示</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Message delay, ms:</source>
        <translation>消息延时(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>StatusIcon</name>
    <message>
        <location filename="../statusicon.cpp" line="39"/>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="40"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="41"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="42"/>
        <source>Next</source>
        <translation>下一曲</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="43"/>
        <source>Previous</source>
        <translation>上一曲</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="45"/>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="96"/>
        <source>Now Playing</source>
        <translation>正在播放</translation>
    </message>
</context>
<context>
    <name>StatusIconFactory</name>
    <message>
        <location filename="../statusiconfactory.cpp" line="30"/>
        <source>Status Icon Plugin</source>
        <translation>状态图标插件</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="50"/>
        <source>Qmmp Status Icon Plugin</source>
        <translation>Qmmp 状态图标插件</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="51"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="49"/>
        <source>About Status Icon Plugin</source>
        <translation>关于状态图标插件</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/General/statusicon/translations/statusicon_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Status Icon Plugin Settings</source>
        <translation>状态图标插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="20"/>
        <source>Show message</source>
        <translation>显示消息</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="27"/>
        <source>Show tooltip</source>
        <translation>显示工具提示</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Message delay, ms:</source>
        <translation>消息延时(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="86"/>
        <source>Use standard icons</source>
        <translation>使用标准图标</translation>
    </message>
</context>
<context>
    <name>StatusIcon</name>
    <message>
        <location filename="../statusicon.cpp" line="46"/>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="47"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="48"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="49"/>
        <source>Next</source>
        <translation>下一曲</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="50"/>
        <source>Previous</source>
        <translation>上一曲</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="52"/>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="127"/>
        <source>Now Playing</source>
        <translation>正在播放</translation>
    </message>
</context>
<context>
    <name>StatusIconFactory</name>
    <message>
        <location filename="../statusiconfactory.cpp" line="30"/>
        <source>Status Icon Plugin</source>
        <translation>状态图标插件</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="51"/>
        <source>Qmmp Status Icon Plugin</source>
        <translation>Qmmp 状态图标插件</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="50"/>
        <source>About Status Icon Plugin</source>
        <translation>关于状态图标插件</translation>
    </message>
</context>
</TS>
